TextCapture class

Inheritance

Constructors

TextCapture({Key? key, required String? licenseKey, bool? isBeepSound, bool? isContinueScan, bool? isVibrate, String? scanType, String? resolution, bool? isAutoExposure, bool? flashLight, bool? isAutoZoom, Color? buttonColor, double? buttonHeight, double? buttonRadius, bool? showScanIcon = false, bool? isLandscape = false, Widget? captureButton, TextCaptureController? controller, Size? designSize, required TextScanResultCallbackHandler textScanResultBackHandler})
const

Properties

buttonColor → Color?
final
buttonHeight → double?
final
buttonRadius → double?
final
captureButton → Widget?
final
controller → TextCaptureController?
final
designSize → Size?
Design reference size used to scale default UI dimensions responsively. If null, defaults to 375x812 (common phone portrait design size).
final
flashLight → bool?
final
hashCode → int
The hash code for this object.
no setterinherited
isAutoExposure → bool?
final
isAutoZoom → bool?
final
isBeepSound → bool?
final
isContinueScan → bool?
final
isLandscape → bool?
final
isVibrate → bool?
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
licenseKey → String?
final
resolution → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scanType → String?
final
showScanIcon → bool?
final
textScanResultBackHandler → TextScanResultCallbackHandler
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → _TextCaptureState
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

initializeModels() → Future<void>